%bcond_with python_bootstrap
%bcond_with tests
%undefine _py3_shebang_s

Summary:       SSH-based configuration management, deployment, and task execution system
Name:          ansible
Version:       2.15.2
Release:       10%{?dist}
License:       GPL-3.0-or-later AND BSD-2-Clause AND PSF-2.0 AND MIT AND Apache-2.0
Url:           https://ansible.com
Source0:       https://github.com/ansible/ansible/archive/refs/tags/v%{version}.tar.gz # /%{name}-%{version}.tar.gz
# download form https://src.fedoraproject.org/rpms/ansible-core/blob/rawhide/f/build_manpages.py 
Source1:       build_manpages.py

Patch0001:     ansible-2.15-fix-cve-2023-5764.patch
Patch0002:     ansible-2.15-fix-cve-2024-0690.patch
#https://github.com/ansible/ansible/pull/84168/commits/c1f3a2aef69746903f79cd11af319ae8d9f92ff3
Patch0003:     ansible-2.15-fix-cve-2024-9902.patch
#https://github.com/ansible/ansible/pull/84182/commits/67276a0913a4c19e4af2c4fd910d6623e7837cab
Patch0004:     ansible-2.15-fix-cve-2024-8775.patch
#https://github.com/ansible/ansible/pull/84353/
Patch0005:     ansible-2.15-fix-cve-2024-11079.patch


BuildArch:     noarch
BuildRequires: make
BuildRequires: python%{python3_pkgversion}-devel
BuildRequires: python%{python3_pkgversion}-argcomplete
# for manpages
BuildRequires: python%{python3_pkgversion}-straight-plugin
BuildRequires: python%{python3_pkgversion}-docutils
%if %{with tests}
BuildRequires: git-core
BuildRequires: glibc-all-langpacks
BuildRequires: python%{python3_pkgversion}-systemd
BuildRequires: /usr/bin/python
%endif

Requires:      python%{python3_pkgversion}-argcomplete
Provides:      ansible-base = %{version}-%{release}
Provides:      ansible-core = %{version}-%{release}
Provides:      bundled(python3dist(backports-ssl-match-hostname)) = 3.7.0.1
Provides:      bundled(python3dist(distro)) = 1.6.0
Provides:      bundled(python3dist(six)) = 1.16.0
Provides:      bundled(python3dist(selectors2)) = 1.1.1
Provides:      bundled(python3dist(ipaddress)) = 1.0.22

%description
Ansible is a radically simple IT automation system. It handles configuration management,
application deployment, cloud provisioning, ad-hoc task execution, network automation,
and multi-node orchestration. Ansible makes complex changes like zero-downtime rolling updates
with load balancers easy. 
Ansible works over SSH and does not require any software or daemons to be installed on remote nodes.
Extension modules can be written in any language and are transferred to managed machines automatically.


%prep
%autosetup -p1 %{name}-%{version}
find \( -name '.git_keep' -o -name '.rstcheck.cfg' \) -delete

sed -i -s 's|/usr/bin/env python|%{python3}|' \
    bin/ansible-test \
    test/lib/ansible_test/_util/target/cli/ansible_test_cli_stub.py

sed -i -e '1{\@^#!.*@d}' lib/ansible/modules/hostname.py
sed '/^mock$/d' test/lib/ansible_test/_data/requirements/units.txt > _requirements.txt

%generate_buildrequires
%pyproject_buildrequires %{?with_tests:_requirements.txt test/units/requirements.txt}


%build
%pyproject_wheel
# manpages
# upstream no provides ability to build manpages from source, build it with the
# fllowing way. For more details, see https://github.com/ansible/ansible/issues/80368
PYTHONPATH="$(pwd)/packaging:%{?with_python_bootstrap:$PYTHONPATH}" %{python3} %{SOURCE1}

# Build shell completions
(
    cd bin
    for shell in bash fish; do
        mkdir -p "../${shell}_completions"
        for bin in *; do
            if grep -q PYTHON_ARGCOMPLETE_OK "${bin}"; then
                case "${shell}" in
                    bash)
                        format="${bin}"
                        ;;
                    fish)
                        format="${bin}.${shell}"
                        ;;
                esac
                register-python-argcomplete --shell "${shell}" "${bin}" > "../${shell}_completions/${format}"
            else
                echo "Skipped generating completions for ${bin}"
            fi
        done
    done
)


%install
%pyproject_install
%pyproject_save_files ansible ansible_test

while read -r file; do
    sed -i -e '1{\@^#!.*@d}' "${file}"
done < <(find \
    %{buildroot}%{python3_sitelib}/ansible/cli/*.py \
    %{buildroot}%{python3_sitelib}/ansible/cli/scripts/ansible_connection_cli_stub.py \
        -type f ! -executable)

install -Dpm 0644 bash_completions/* -t %{buildroot}%{bash_completions_dir}
install -Dpm 0644 fish_completions/* -t %{buildroot}%{fish_completions_dir}

DATADIR_LOCATIONS='%{_datadir}/ansible/collections
%{_datadir}/ansible/collections/ansible_collections
%{_datadir}/ansible/plugins/doc_fragments
%{_datadir}/ansible/plugins/action
%{_datadir}/ansible/plugins/become
%{_datadir}/ansible/plugins/cache
%{_datadir}/ansible/plugins/callback
%{_datadir}/ansible/plugins/cliconf
%{_datadir}/ansible/plugins/connection
%{_datadir}/ansible/plugins/filter
%{_datadir}/ansible/plugins/httpapi
%{_datadir}/ansible/plugins/inventory
%{_datadir}/ansible/plugins/lookup
%{_datadir}/ansible/plugins/modules
%{_datadir}/ansible/plugins/module_utils
%{_datadir}/ansible/plugins/netconf
%{_datadir}/ansible/roles
%{_datadir}/ansible/plugins/strategy
%{_datadir}/ansible/plugins/terminal
%{_datadir}/ansible/plugins/test
%{_datadir}/ansible/plugins/vars'

UPSTREAM_DATADIR_LOCATIONS=$(grep -ri default lib/ansible/config/base.yml| tr ':' '\n' | grep '/usr/share/ansible')

if [ "$SYSTEM_LOCATIONS" != "$UPSTREAM_SYSTEM_LOCATIONS" ] ; then
  echo "The upstream Ansible datadir locations have changed.  Spec file needs to be updated"
  exit 1
fi

mkdir -p %{buildroot}%{_datadir}/ansible/plugins/
for location in $DATADIR_LOCATIONS ; do
    mkdir %{buildroot}"$location"
done
mkdir -p %{buildroot}%{_sysconfdir}/ansible/
mkdir -p %{buildroot}%{_sysconfdir}/ansible/roles/

cp examples/hosts %{buildroot}/etc/ansible/
cp examples/ansible.cfg %{buildroot}/etc/ansible/
mkdir -p %{buildroot}/%{_mandir}/man1
cp -v docs/man/man1/*.1 %{buildroot}/%{_mandir}/man1/

find %{buildroot}/%{python3_sitelib} -name .travis.yml -type f -delete

%global _pkglicensedir %{_licensedir}/ansible-core
install -Dpm 0644 licenses/* -t %{buildroot}%{_pkglicensedir}


%check
%if %{with tests}
ln -s /usr/bin/pytest-3 bin/pytest
make PYTHON=%{python3} tests-py3
%endif


%files -f %{pyproject_files}
%license COPYING
%license %{_pkglicensedir}/{Apache-License,MIT-license,PSF-license,simplified_bsd}.txt
%doc README.rst changelogs/CHANGELOG-v2.1?.rst docs/docsite/rst
%dir %{_sysconfdir}/ansible/
%config(noreplace) %{_sysconfdir}/ansible/*
%{_bindir}/ansible*
%{_datadir}/ansible/
%{bash_completions_dir}/ansible*
%{fish_completions_dir}/ansible*.fish
%{_mandir}/man1/ansible*


%changelog
* Mon May 19 2025 wynnfeng <wynnfeng@tencent.com> - 2.15.2-10
- [type] security
- [desc] fix CVE-2024-11079 

* Wed Dec 11 2024 wynnfeng <wynnfeng@tencent.com> - 2.15.2-9
- [type] security
- [desc] fix cve-2024-8775

* Mon Dec 02 2024 wynnfeng <wynnfeng@tencent.com> - 2.15.2-8
- [type] security
- [desc] fix cve-2024-9902

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.15.2-7
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.15.2-6
- Rebuilt for loongarch release

* Mon Feb 19 2024 wynnfeng <wynnfeng@tencent.com> - 2.15.2-5
- fix CVE-2023-5764 and CVE-2024-0690

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.15.2-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.15.2-3
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Sep 7 2023 Shuo Wang <abushwang@tencent.com> - 2.15.2-2
- add bootstrap for python3.11

* Wed Jul 19 2023 kianli <kianli@tencent.com> - 2.15.2-1
- Upgrade to 2.15.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.0-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Nov 29 2022 rockerzhu <rockerzhu@tencent.com> - 2.14.0-1
- Initial build
